==> ci-hotel_V1.0.0_20101217.zip: ci-hotel_1.0.0_20101217/system/application/views/admin/hotel/index.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<style type="text/css">
@import "<?php echo base_url() ?>/js/jquery.timeentry.package-1.4.8/jquery.timeentry.css";
</style>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/jquery.timeentry.js"></script>
<script type="text/javascript">
$(function () {
	$('#time1').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '15:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
	$('#time2').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '23:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
	$('#time3').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '10:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
});
</script>
<link rel="stylesheet" href="<?php echo base_url() ?>css/ui.spinner.css">
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.core.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.spinner.js"></script>
    <script>
    $(document).ready(function(){
        $("#s1").spinner({max: 20, min: 0});
        $("#s2").spinner({max: 20, min: 0});
    });
    </script>
<?php
include(dirname(__FILE__) . '/../header2.php');
?>

<h2>ホテル情報</h2>

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err)
    {
        echo "<li>" . $err . "</li>" . "\n";
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('admin/hotel/index'); ?>

<table class="inp">
<tr><th>* ホテル名称 :</th><td>
<input type="text" name="hotel_name" value="<?php echo set_value('hotel_name', isset($hotel_name) ? $hotel_name : ''); ?>" size="80" />
<?php echo form_error('hotel_name'); ?>
</td></tr>
<tr><th>* 管理者メールアドレス :</th><td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="80" />
<?php echo form_error('email'); ?>
</td></tr>
<tr><th>URL :</th><td>
<input type="text" name="url" value="<?php echo set_value('url', isset($url) ? $url : ''); ?>" size="80" />
<?php echo form_error('url'); ?>
</td></tr>
<tr><th>* 予約可能日(日前) :</th><td>
<input type="text" name="res_prev_days" id="s1" value="<?php echo set_value('res_prev_days', isset($res_prev_days) ? $res_prev_days : ''); ?>" size="2" />
<?php echo form_error('res_prev_days'); ?>
</td></tr>
<tr><th>* 予約可能期間(ヶ月) :</th><td>
<input type="text" name="res_term" id="s2" value="<?php echo set_value('res_term', isset($res_term) ? $res_term : ''); ?>" size="2" />
<?php echo form_error('res_term'); ?>
</td></tr>
<tr><th>* 予約方法 :</th><td>
<label>
<input type="checkbox" name="tentative_reservation" value="1" <?php echo set_checkbox('tentative_reservation', '1', isset($tentative_reservation) && $tentative_reservation == 1 ? true : false);?>/>仮予約
</label>
</td></tr>
<tr><th>* チェックイン時刻 :</th><td>
<input type="text" name="cin_hour" id="time1" value="<?php echo set_value('cin_hour', isset($cin_hour) ? $cin_hour : ''); ?>" size="20" />
～
<input type="text" name="cin_hour2" id="time2" value="<?php echo set_value('cin_hour2', isset($cin_hour2) ? $cin_hour2 : ''); ?>" size="20" />
</td></tr>
<tr><th>* チェックアウト時刻 :</th><td>
<input type="text" name="cout_hour" id="time3" value="<?php echo set_value('cout_hour', isset($cout_hour) ? $cout_hour : ''); ?>" size="20" />
</td></tr>
<tr><th>* 郵便番号 :</th><td>
<input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" />
<?php echo form_error('postcode'); ?>
</td></tr>
<tr><th>* 都道府県 :</th><td>
<?php
$prefecture_options = array(
    '' => '--', '北海道' => '北海道',
    '青森県' => '青森県', '岩手県' => '岩手県', '宮城県' => '宮城県', '秋田県' => '秋田県',
    '山形県' => '山形県', '福島県' => '福島県', '茨城県' => '茨城県', '栃木県' => '栃木県',
    '群馬県' => '群馬県', '埼玉県' => '埼玉県', '千葉県' => '千葉県', '東京都' => '東京都',
    '神奈川県' => '神奈川県', '新潟県' => '新潟県', '富山県' => '富山県', '石川県' => '石川県',
    '福井県' => '福井県', '山梨県' => '山梨県', '長野県' => '長野県', '岐阜県' => '岐阜県',
    '静岡県' => '静岡県', '愛知県' => '愛知県', '三重県' => '三重県', '滋賀県' => '滋賀県',
    '京都府' => '京都府', '大阪府' => '大阪府', '兵庫県' => '兵庫県', '奈良県' => '奈良県',
    '和歌山県' => '和歌山県', '鳥取県' => '鳥取県', '島根県' => '島根県', '岡山県' => '岡山県',
    '広島県' => '広島県', '山口県' => '山口県', '徳島県' => '徳島県', '香川県' => '香川県',
    '愛媛県' => '愛媛県', '高知県' => '高知県', '福岡県' => '福岡県', '佐賀県' => '佐賀県',
    '長崎県' => '長崎県', '熊本県' => '熊本県', '大分県' => '大分県', '宮崎県' => '宮崎県',
    '鹿児島県' => '鹿児島県', '沖縄県' => '沖縄県'
);
echo form_dropdown('prefecture', $prefecture_options, set_value('prefecture', isset($prefecture) ? $prefecture : ''));
echo form_error('prefecture');
?>
</td></tr>
<tr><th>* 市区町村 :</th>
<td>
<input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" />
<?php echo form_error('city'); ?>
</td></tr>
<tr><th>* 番地 :</th>
<td>
<input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" />
<?php echo form_error('street'); ?>
</td></tr>
<tr><th>* 電話番号 :</th>
<td>
<input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" />
<?php echo form_error('phone'); ?>
</td></tr>
</table>
<input type="submit" name="submit" value="ホテル情報を更新する" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>

==> ci-hotel_V1.2.0_20110206.zip: ci-hotel_1.2.0_20110206/system/application/views/admin/hotel/index.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<style type="text/css">
@import "<?php echo base_url() ?>/js/jquery.timeentry.package-1.4.8/jquery.timeentry.css";
</style>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/jquery.timeentry.js"></script>
<script type="text/javascript">
$(function () {
	$('#time1').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '15:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
	$('#time2').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '23:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
	$('#time3').timeEntry({show24Hours: true, timeSteps: [0, 30, 0], defaultTime: '10:00', spinnerImage: '<?php echo base_url() ?>js/jquery.timeentry.package-1.4.8/spinnerDefault.png'});
});
</script>
<link rel="stylesheet" href="<?php echo base_url() ?>css/ui.spinner.css">
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.core.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.spinner.js"></script>
    <script>
    $(document).ready(function(){
        $("#s1").spinner({max: 20, min: 0});
        $("#s2").spinner({max: 20, min: 0});
    });
    </script>
<?php
include(dirname(__FILE__) . '/../header2.php');
?>

<h2>ホテル情報</h2>

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err)
    {
        echo "<li>" . $err . "</li>" . "\n";
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('admin/hotel/index/' . $hotelid); ?>

<table class="inp">
<tr><th>* ホテル名称 :</th><td>
<input type="text" name="hotel_name" value="<?php echo set_value('hotel_name', isset($hotel_name) ? $hotel_name : ''); ?>" size="80" />
<?php echo form_error('hotel_name'); ?>
</td></tr>
<tr><th>* 管理者メールアドレス :</th><td>
<input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="80" />
<?php echo form_error('email'); ?>
</td></tr>
<tr><th>URL :</th><td>
<input type="text" name="url" value="<?php echo set_value('url', isset($url) ? $url : ''); ?>" size="80" />
<?php echo form_error('url'); ?>
</td></tr>
<tr><th>* 予約可能日(日前) :</th><td>
<input type="text" name="res_prev_days" id="s1" value="<?php echo set_value('res_prev_days', isset($res_prev_days) ? $res_prev_days : ''); ?>" size="2" />
<?php echo form_error('res_prev_days'); ?>
</td></tr>
<tr><th>* 予約可能期間(ヶ月) :</th><td>
<input type="text" name="res_term" id="s2" value="<?php echo set_value('res_term', isset($res_term) ? $res_term : ''); ?>" size="2" />
<?php echo form_error('res_term'); ?>
</td></tr>
<tr><th>* 予約方法 :</th><td>
<label>
<input type="checkbox" name="tentative_reservation" value="1" <?php echo set_checkbox('tentative_reservation', '1', isset($tentative_reservation) && $tentative_reservation == 1 ? true : false);?>/>仮予約
</label>
</td></tr>
<tr><th>* チェックイン時刻 :</th><td>
<input type="text" name="cin_hour" id="time1" value="<?php echo set_value('cin_hour', isset($cin_hour) ? $cin_hour : ''); ?>" size="20" />
～
<input type="text" name="cin_hour2" id="time2" value="<?php echo set_value('cin_hour2', isset($cin_hour2) ? $cin_hour2 : ''); ?>" size="20" />
<?php echo form_error('cin_hour'); ?>
<?php echo form_error('cin_hour2'); ?>
</td></tr>
<tr><th>* チェックアウト時刻 :</th><td>
<input type="text" name="cout_hour" id="time3" value="<?php echo set_value('cout_hour', isset($cout_hour) ? $cout_hour : ''); ?>" size="20" />
<?php echo form_error('cout_hour'); ?>
</td></tr>
<tr><th>* 郵便番号 :</th><td>
<input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" />
<?php echo form_error('postcode'); ?>
</td></tr>
<tr><th>* 都道府県 :</th><td>
<?php
$prefecture_options = array(
    '' => '--', '北海道' => '北海道',
    '青森県' => '青森県', '岩手県' => '岩手県', '宮城県' => '宮城県', '秋田県' => '秋田県',
    '山形県' => '山形県', '福島県' => '福島県', '茨城県' => '茨城県', '栃木県' => '栃木県',
    '群馬県' => '群馬県', '埼玉県' => '埼玉県', '千葉県' => '千葉県', '東京都' => '東京都',
    '神奈川県' => '神奈川県', '新潟県' => '新潟県', '富山県' => '富山県', '石川県' => '石川県',
    '福井県' => '福井県', '山梨県' => '山梨県', '長野県' => '長野県', '岐阜県' => '岐阜県',
    '静岡県' => '静岡県', '愛知県' => '愛知県', '三重県' => '三重県', '滋賀県' => '滋賀県',
    '京都府' => '京都府', '大阪府' => '大阪府', '兵庫県' => '兵庫県', '奈良県' => '奈良県',
    '和歌山県' => '和歌山県', '鳥取県' => '鳥取県', '島根県' => '島根県', '岡山県' => '岡山県',
    '広島県' => '広島県', '山口県' => '山口県', '徳島県' => '徳島県', '香川県' => '香川県',
    '愛媛県' => '愛媛県', '高知県' => '高知県', '福岡県' => '福岡県', '佐賀県' => '佐賀県',
    '長崎県' => '長崎県', '熊本県' => '熊本県', '大分県' => '大分県', '宮崎県' => '宮崎県',
    '鹿児島県' => '鹿児島県', '沖縄県' => '沖縄県'
);
echo form_dropdown('prefecture', $prefecture_options, set_value('prefecture', isset($prefecture) ? $prefecture : ''));
echo form_error('prefecture');
?>
</td></tr>
<tr><th>* 市区町村 :</th>
<td>
<input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" />
<?php echo form_error('city'); ?>
</td></tr>
<tr><th>* 番地 :</th>
<td>
<input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" />
<?php echo form_error('street'); ?>
</td></tr>
<tr><th>* 電話番号 :</th>
<td>
<input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" />
<?php echo form_error('phone'); ?>
</td></tr>
</table>
<input type="submit" name="submit" value="ホテル情報を更新する" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>
